# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import requests

from xingchen import Configuration, ApiClient, ChatReqParams, CharacterKey, Message, AdvancedSettings, Scenario
from xingchen.api.chat_api_sub import ChatApiSub  # noqa: E501


class TestChatApiSub(unittest.TestCase):
    """ChatApiSub unit test stubs"""
    def setUp(self) -> None:
        configuration = Configuration(
            host="https://pre-xingchen.aliyun.com",
        )
        result = requests.get("https://alimt-plugins.alibaba.com/api/auth/refresh?token=0aSUXbPxRzEeIXU7")
        access_token = result.content.decode("utf-8")
        print(access_token)
        configuration.access_token = access_token
        with ApiClient(configuration) as api_client:
            self.api = ChatApiSub(api_client)  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_chat(self) -> None:
        """Test case for chat

        用户对话  # noqa: E501
        """
        chat_req_params = {
            "botProfile": {
                "characterId": "77d0e93e1ce240f582c46d0b812a558a", "version": 1
            },
            "advancedSettings": {
                "enableWebSearch": True,
                "enableCharacterKbSearch": True,
                "enableLongTermMemory": True,
                "enableDebug": False
            },
            "modelParameters": {
                "modelName": "", "topP": 0.8, "topK": 100, "seed": 1234
            },
            "userProfile": {
                "userId": "123456789", "userName": "云账号名称", "basicInfo": ""
            },
            "scenario": {
                "description": "我是赵云，想拜关云长为二哥"
            },
            "messages": [
                {
                    "role": "user", "name": "小明", "content": "你有几个兄弟"
                }
            ]
        }  # ChatReqParams | 对话请求
        api_response = self.api.chat(chat_req_params)
        print("The response of ChatApiSub->chat:\n")
        print(api_response)
        pass

    def test_chat_v2(self) -> None:
        """Test case for chat_v2

        用户对话v2  # noqa: E501
        """
        pass

    def test_custom_chat(self) -> None:
        """Test case for custom_chat

        用户对话  # noqa: E501
        """
        pass

    def test_custom_chat1(self) -> None:
        """Test case for custom_chat1

        用户对话  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class Context(BaseModel):
    """
    Context
    """
    chat_room_id: Optional[StrictInt] = Field(None, alias="chatRoomId")
    session_id: Optional[StrictStr] = Field(None, alias="sessionId")
    chat_id: Optional[StrictStr] = Field(None, alias="chatId")
    message_id: Optional[StrictStr] = Field(None, alias="messageId") # 模型回复消息ID，请使用 answer_id
    reply_message_id: Optional[StrictStr] = Field(None, alias="replyMessageId") # 用户提问消息ID，请使用 query_id
    enable_data_inspection: Optional[StrictBool] = Field(None, alias="enableDataInspection")
    answer_id: Optional[StrictStr] = Field(None, alias="answerId")
    query_id: Optional[StrictStr] = Field(None, alias="queryId")
    is_save: Optional[StrictBool] = Field(None, alias="isSave")
    request_id: Optional[StrictStr] = Field(None, alias="requestId")
    model_request_id: Optional[StrictStr] = Field(None, alias="modelRequestId")
    character_pk: Optional[StrictInt] = Field(None, alias="characterPk")
    model_name: Optional[StrictStr] = Field(None, alias="modelName")
    __properties = ["chatRoomId", "sessionId", "chatId", "messageId", "replyMessageId", "answerId", "queryId", "enableDataInspection", "isSave", "requestId", "modelRequestId", "characterPk", "modelName"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Context:
        """Create an instance of Context from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Context:
        """Create an instance of Context from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Context.parse_obj(obj)

        _obj = Context.parse_obj({
            "chat_room_id": obj.get("chatRoomId"),
            "session_id": obj.get("sessionId"),
            "chat_id": obj.get("chatId"),
            "message_id": obj.get("messageId"),
            "reply_message_id": obj.get("replyMessageId"),
            "answer_id": obj.get("answerId"),
            "query_id": obj.get("queryId"),
            "enable_data_inspection": obj.get("enableDataInspection"),
            "is_save": obj.get("isSave"),
            "request_id": obj.get("requestId"),
            "model_request_id": obj.get("modelRequestId"),
            "character_pk": obj.get("characterPk"),
            "model_name": obj.get("modelName")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class CharacterKey(BaseModel):
    """
    CharacterKey
    """
    character_id: Optional[StrictStr] = Field(None, alias="characterId")
    version: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    content: Optional[StrictStr] = None
    type: Optional[StrictStr] = Field(None, alias="type", description="角色类型，虚拟角色-virtual（默认）, 角色复刻-reproduction，助手-assistant")
    task: Optional[StrictStr] = Field(None, alias="task", description="角色群聊任务")
    traits: Optional[StrictStr] = Field(None, alias="traits", description="强制要求")
    __properties = ["characterId", "version", "name", "content", "type", "task", "traits"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterKey:
        """Create an instance of CharacterKey from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterKey:
        """Create an instance of CharacterKey from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterKey.parse_obj(obj)

        _obj = CharacterKey.parse_obj({
            "character_id": obj.get("characterId"),
            "version": obj.get("version"),
            "name": obj.get("name"),
            "content": obj.get("content"),
            "task": obj.get("task"),
            "traits": obj.get("traits")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.message import Message  # noqa: E501

class TestMessage(unittest.TestCase):
    """Message unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Message:
        """Test Message
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Message`
        """
        model = Message()  # noqa: E501
        if include_optional:
            return Message(
                name = '',
                role = '',
                content = '',
                finish_reason = '',
                meta = xingchen.models.meta.Meta(
                    has_risk = True, 
                    safety_std_answer = '', )
            )
        else:
            return Message(
        )
        """

    def testMessage(self):
        """Test Message"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO  # noqa: E501

class TestPageResultChatMessageDTO(unittest.TestCase):
    """PageResultChatMessageDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageResultChatMessageDTO:
        """Test PageResultChatMessageDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageResultChatMessageDTO`
        """
        model = PageResultChatMessageDTO()  # noqa: E501
        if include_optional:
            return PageResultChatMessageDTO(
                list = [
                    xingchen.models.chat_message_dto.ChatMessageDTO(
                        content = '', 
                        message_type = '', 
                        message_id = '', 
                        message_issuer = xingchen.models.chat_room_user_dto.ChatRoomUserDTO(
                            user_id = '', 
                            biz_user_id = '', 
                            user_name = '', 
                            user_type = '', ), 
                        session_id = '', 
                        chat_id = '', 
                        gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_greeting = True, 
                        rating = 1.337, 
                        regenerate_times = 56, )
                    ],
                page = 56,
                page_size = 56,
                total = 56,
                page_offset_value = 56
            )
        else:
            return PageResultChatMessageDTO(
        )
        """

    def testPageResultChatMessageDTO(self):
        """Test PageResultChatMessageDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, conlist
from xingchen.models.chat_message_dto import ChatMessageDTO

class PageResultChatMessageDTO(BaseModel):
    """
    PageResultChatMessageDTO
    """
    list: Optional[conlist(ChatMessageDTO)] = None
    page: Optional[StrictInt] = None
    page_size: Optional[StrictInt] = Field(None, alias="pageSize")
    total: Optional[StrictInt] = None
    page_offset_value: Optional[StrictInt] = Field(None, alias="pageOffsetValue")
    __properties = ["list", "page", "pageSize", "total", "pageOffsetValue"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PageResultChatMessageDTO:
        """Create an instance of PageResultChatMessageDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in list (list)
        _items = []
        if self.list:
            for _item in self.list:
                if _item:
                    _items.append(_item.to_dict())
            _dict['list'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PageResultChatMessageDTO:
        """Create an instance of PageResultChatMessageDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PageResultChatMessageDTO.parse_obj(obj)

        _obj = PageResultChatMessageDTO.parse_obj({
            "list": [ChatMessageDTO.from_dict(_item) for _item in obj.get("list")] if obj.get("list") is not None else None,
            "page": obj.get("page"),
            "page_size": obj.get("pageSize"),
            "total": obj.get("total"),
            "page_offset_value": obj.get("pageOffsetValue")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from xingchen.models.gateway_context import GatewayContext

class GatewayIssuedParams(BaseModel):
    """
    GatewayIssuedParams
    """
    user_info: Optional[Dict[str, StrictStr]] = Field(None, alias="userInfo")
    context: Optional[GatewayContext] = None
    __properties = ["userInfo", "context"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GatewayIssuedParams:
        """Create an instance of GatewayIssuedParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of context
        if self.context:
            _dict['context'] = self.context.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GatewayIssuedParams:
        """Create an instance of GatewayIssuedParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GatewayIssuedParams.parse_obj(obj)

        _obj = GatewayIssuedParams.parse_obj({
            "user_info": obj.get("userInfo"),
            "context": GatewayContext.from_dict(obj.get("context")) if obj.get("context") is not None else None
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from xingchen.api.chat_message_api_sub import ChatMessageApiSub  # noqa: E501


class TestChatMessageApiSub(unittest.TestCase):
    """ChatMessageApiSub unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatMessageApiSub()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_chat_histories(self) -> None:
        """Test case for chat_histories

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories1(self) -> None:
        """Test case for chat_histories1

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories2(self) -> None:
        """Test case for chat_histories2

        对话历史  # noqa: E501
        """
        pass

    def test_chat_histories3(self) -> None:
        """Test case for chat_histories3

        对话历史  # noqa: E501
        """
        pass

    def test_rate_message(self) -> None:
        """Test case for rate_message

        消息评分  # noqa: E501
        """
        pass

    def test_rate_message1(self) -> None:
        """Test case for rate_message1

        消息评分  # noqa: E501
        """
        pass

    def test_sys_reminder(self) -> None:
        """Test case for sys_reminder

        """
        pass

    def test_sys_reminder1(self) -> None:
        """Test case for sys_reminder1

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from xingchen.models.advanced_settings import AdvancedSettings
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.character_advanced_config import CharacterAdvancedConfig
from xingchen.models.character_create_dto import CharacterCreateDTO
from xingchen.models.character_dto import CharacterDTO
from xingchen.models.character_key import CharacterKey
from xingchen.models.character_permission_config import CharacterPermissionConfig
from xingchen.models.character_query_dto import CharacterQueryDTO
from xingchen.models.character_query_where import CharacterQueryWhere
from xingchen.models.character_update_dto import CharacterUpdateDTO
from xingchen.models.character_version_create_or_update_dto import CharacterVersionCreateOrUpdateDTO
from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO
from xingchen.models.chat_history_query_where import ChatHistoryQueryWhere
from xingchen.models.chat_message_dto import ChatMessageDTO
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.chat_room_user_dto import ChatRoomUserDTO
from xingchen.models.context import Context
from xingchen.models.file_info_vo import FileInfoVO
from xingchen.models.gateway_context import GatewayContext
from xingchen.models.gateway_issued_params import GatewayIssuedParams
from xingchen.models.input import Input
from xingchen.models.message import Message
from xingchen.models.message_rating_request import MessageRatingRequest
from xingchen.models.meta import Meta
from xingchen.models.model_parameters import ModelParameters
from xingchen.models.page_result_character_dto import PageResultCharacterDTO
from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO
from xingchen.models.repository import Repository
from xingchen.models.repository_info import RepositoryInfo
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO
from xingchen.models.result_dto_character_key import ResultDTOCharacterKey
from xingchen.models.result_dto_list_character_dto import ResultDTOListCharacterDTO
from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO
from xingchen.models.result_dto_page_result_chat_message_dto import ResultDTOPageResultChatMessageDTO
from xingchen.models.scenario import Scenario
from xingchen.models.sys_reminder_request import SysReminderRequest
from xingchen.models.user_profile import UserProfile
from xingchen.models.result_dto_extract_summary_dto import ResultDTOExtractSummaryDTO
from xingchen.models.result_dto_extract_kv_dto import ResultDTOExtractKVDTO
from xingchen.models.result_dto_polling_image_detail_dto import ResultDTOPollingImageDetailDTO
from xingchen.models.result_dto_file_conver_dto import ResultDTOFileConvertDTO
from xingchen.models.result_dto_character_desc_dto import ResultDTOCharacterDescDTO



# coding: utf-8

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr


class ChatContext(BaseModel):
    use_chat_history: Optional[bool] = Field(None, alias="useChatHistory", description="是否使用平台对话历史，默认是")
    is_regenerate: Optional[bool] = Field(None, alias="isRegenerate", description="""
    是否重新生成
    true: 重新生成
    - 如果使用平台对话历史
        - messages 会被忽略
        - queryId 不能为空
    - 如果不使用平台历史
        - 可以不传 queryId, messages 和 随机因子 parameter.seed 需要用户提供
    """)
    query_id: Optional[StrictStr] = Field(None, alias="queryId", description="重新生成且使用平台历史时，该值必传，不使用平台历史时，该值可以不传")
    answer_id: Optional[StrictStr] = Field(None, alias="answerId", description="若 answerId 不为空，认为是重新生成后的新一轮对话，该 answerId 为最后轮对话中多个回复中的一条消息ID")
    result_count: Optional[StrictInt] = Field(None, alias="resultCount", description="生成结果数量，若同一个问题需生成多条结果，只能使用同步调用，默认只能生成1条结果")
    __properties = ["useChatHistory", "isRegenerate", "queryId", "answerId", "resultCount"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatContext:
        """Create an instance of Context from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatContext:
        """Create an instance of Context from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatContext.parse_obj(obj)

        _obj = ChatContext.parse_obj({
            "use_chat_history": obj.get("useChatHistory"),
            "is_regenerate": obj.get("isRegenerate"),
            "query_id": obj.get("queryId"),
            "answer_id": obj.get("answerId"),
            "result_count": obj.get("resultCount"),
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.gateway_issued_params import GatewayIssuedParams  # noqa: E501

class TestGatewayIssuedParams(unittest.TestCase):
    """GatewayIssuedParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GatewayIssuedParams:
        """Test GatewayIssuedParams
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GatewayIssuedParams`
        """
        model = GatewayIssuedParams()  # noqa: E501
        if include_optional:
            return GatewayIssuedParams(
                user_info = {
                    'key' : ''
                    },
                context = xingchen.models.gateway_context.GatewayContext(
                    service_type = '', 
                    fc_url = '', 
                    flow_json_path = '', )
            )
        else:
            return GatewayIssuedParams(
        )
        """

    def testGatewayIssuedParams(self):
        """Test GatewayIssuedParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

from __future__ import annotations

import json
import pprint
import re
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictStr

from xingchen.models.input import Input
from xingchen.models.model_parameters import ModelParameters


class BaseChatRequest(BaseModel):
    """
    BaseChatRequestAcaChatExtParam
    """
    model: Optional[StrictStr] = None
    parameters: Optional[ModelParameters] = None
    input: Input = Field(...)
    servicename: Optional[StrictStr] = None
    debug: Optional[StrictBool] = None
    __properties = ["model", "parameters", "input", "servicename", "debug"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BaseChatRequest:
        """Create an instance of BaseChatRequestAcaChatExtParam from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of parameters
        if self.parameters:
            _dict['parameters'] = self.parameters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of input
        if self.input:
            _dict['input'] = self.input.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BaseChatRequest:
        """Create an instance of BaseChatRequestAcaChatExtParam from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BaseChatRequest.parse_obj(obj)

        _obj = BaseChatRequest.parse_obj({
            "model": obj.get("model"),
            "parameters": ModelParameters.from_dict(obj.get("parameters")) if obj.get("parameters") is not None else None,
            "input": Input.from_dict(obj.get("input")) if obj.get("input") is not None else None,
            "servicename": obj.get("servicename"),
            "debug": obj.get("debug")
        })
        return _obj





# coding: utf-8
from __future__ import annotations

import json
import pprint

from pydantic import BaseModel, Field, StrictStr, StrictInt, conlist
from typing import Optional, Any

from xingchen.models.message import Message
from xingchen.models.context import Context
from xingchen.models.custom.base_response import BaseResponse


class Choice(BaseModel):
    stop_reason: Optional[StrictStr] = Field(None, alias="stopReason")
    messages: Optional[conlist(Message)] = Field(None, alias="messages")
    __properties = ["stopReason", "messages"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> Choice:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> Choice:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Choice.parse_obj(obj)

        return Choice.parse_obj({
            'stop_reason': obj.get('stopReason'),
            'messages': obj.get('messages')
        })


class Usage(BaseModel):
    user_tokens: Optional[StrictInt] = Field(None, alias="userTokens")
    input_tokens: Optional[StrictInt] = Field(None, alias="inputTokens")
    output_tokens: Optional[StrictInt] = Field(None, alias="outputTokens")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> Usage:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> Usage:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Usage.parse_obj(obj)

        return Usage.parse_obj({
            'user_tokens': obj.get('userTokens'),
            'input_tokens': obj.get('inputTokens'),
            'output_tokens': obj.get('outputTokens')
        })


class ChatResult(BaseModel):
    choices: Optional[conlist(Choice)] = Field(None, alias="choices")
    usage: Optional[Usage] = Field(None, alias="usage")
    context: Optional[Context] = Field(None, alias="context")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> ChatResult:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> ChatResult:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatResult.parse_obj(obj)

        return ChatResult.parse_obj({
            'choices': obj.get('choices'),
            'usage': obj.get('usage'),
            'context': obj.get('context')
        })


class ChatResponse(BaseResponse):
    data: Optional[ChatResult] = Field(None, alias="chatResult")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=False, exclude_none=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=False, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> ChatResponse:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> ChatResponse | None:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatResponse.parse_obj(obj)

        return ChatResponse.parse_obj({
            'request_id': obj.get('requestId'),
            'error_code': obj.get('errorCode'),
            'error_message': obj.get('errorMessage'),
            'error_name': obj.get('errorName'),
            'http_status_code': obj.get('httpStatusCode'),
            'code': obj.get('code'),
            'error_message_key': obj.get('errorMessageKey'),
            'success': obj.get('success'),
            'data': obj.get('data')
        })



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.page_result_character_dto import PageResultCharacterDTO  # noqa: E501

class TestPageResultCharacterDTO(unittest.TestCase):
    """PageResultCharacterDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageResultCharacterDTO:
        """Test PageResultCharacterDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PageResultCharacterDTO`
        """
        model = PageResultCharacterDTO()  # noqa: E501
        if include_optional:
            return PageResultCharacterDTO(
                list = [
                    xingchen.models.character_dto.CharacterDTO(
                        name = '0', 
                        avatar = xingchen.models.file_info_vo.FileInfoVO(
                            file_save_path = '', 
                            filename = '', 
                            file_url = '', ), 
                        introduction = '', 
                        basic_information = '', 
                        opening_line = '', 
                        traits = '', 
                        chat_example = '', 
                        type = '', 
                        chat_objective = '', 
                        advanced_config = xingchen.models.character_advanced_config.CharacterAdvancedConfig(
                            repository_info = xingchen.models.repository_info.RepositoryInfo(
                                repository_files = [
                                    xingchen.models.repository.Repository(
                                        file_save_path = '', 
                                        filename = '', 
                                        file_url = '', 
                                        status = '', )
                                    ], 
                                status = '', ), 
                            is_real_info = True, 
                            search_keyword = '', 
                            allow_send_image = True, 
                            image_style = '', 
                            allow_send_asr = True, 
                            asr_style = '', 
                            chat_description = '', ), 
                        character_id = '', 
                        version = 56, 
                        major_version = 56, 
                        gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        gmt_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        user_id = '', 
                        modified_by = '', 
                        tags = [
                            ''
                            ], 
                        bubbles = [
                            ''
                            ], 
                        background_img_url = '', 
                        perm_config = xingchen.models.character_permission_config.CharacterPermissionConfig(
                            is_public = 56, 
                            allow_chat = 56, 
                            allow_api = 56, ), 
                        versions = [
                            56
                            ], 
                        manageable = True, 
                        creator = '', 
                        is_pre_configured = True, )
                    ],
                page = 56,
                page_size = 56,
                total = 56,
                page_offset_value = 56
            )
        else:
            return PageResultCharacterDTO(
        )
        """

    def testPageResultCharacterDTO(self):
        """Test PageResultCharacterDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    通义星尘开放接口Python SDK，详情可以参考官方文档 https://tongyi.aliyun.com/xingchen/document

"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "xingchen"
VERSION = "1.1.3"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3, < 2.1.0",
    "python-dateutil",
    "pydantic >= 1.10.5, < 2",
    "aenum",
    "sseclient-py >= 1.8.0"
]

setup(
    name=NAME,
    version=VERSION,
    description="XingChen 开放接口定义",
    author="zhiyong.fzy",
    author_email="zhiyong.fzy@alibaba-inc.com",
    url="",
    keywords=["XingChen", "Character AI", "XingChen开放接口定义"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests", "demo"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    通义星尘(https://tongyi.aliyun.com/xingchen) Python SDK 
    """,  # noqa: E501
    package_data={"xingchen": ["py.typed"]},
)



# coding: utf-8

import json

from pydantic import BaseModel, Field, conlist

from xingchen.models.character_key import CharacterKey
from xingchen.models.custom.groupchat.group_chat_reply_setting import GroupChatReplySetting
from xingchen.models.custom.groupchat.group_chat_room_info import GroupChatRoomInfo
from xingchen.models.user_profile import UserProfile


class GroupChatExtParam(BaseModel):
    """
    GroupChatExtParam
    """
    bot_profiles: conlist(CharacterKey, max_items=10, min_items=1) = Field(..., alias="botProfiles",
                                                                           description="群聊角色定义")
    reply_setting: GroupChatReplySetting = Field(..., alias="replySetting", description="回复设置")
    user_profile: UserProfile = Field(..., alias="userProfile", description="用户角色定义")
    group_info: GroupChatRoomInfo = Field(..., alias="groupInfo", description="群聊信息")
    __properties = ["botProfiles", "replySetting", "userProfile", "groupInfo"]

    def to_str(self) -> str:
        # 直接使用 json.dumps 序列化，提高性能效率
        return json.dumps(self.dict(by_alias=True, exclude_none=True), indent=4)

    def to_json(self) -> str:
        # 同样，直接序列化，避免不必要的中间步骤
        return json.dumps(self.dict(by_alias=True, exclude_none=True))

    def to_dict(self):
        # 简化了代码风格
        return self.dict(by_alias=True, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> 'GroupChatExtParam':
        # 增加异常处理来确保输入的 JSON 字符串是有效的
        try:
            obj_dict = json.loads(json_str)
            return cls.from_dict(obj_dict)
        except json.JSONDecodeError:
            raise ValueError("Invalid JSON string")

    @classmethod
    def from_dict(cls, obj: dict) -> 'GroupChatExtParam':
        # 移除了对 `obj` 是否为 `None` 的判断，因为 `parse_obj` 已经能够处理 `None` 的情况
        # 同时，明确使用 `cls.__init__` 来创建实例，提高代码的可维护性和健壮性
        if not isinstance(obj, dict):
            raise TypeError("Expected a dictionary object")

        return cls(
            bot_profiles=CharacterKey.from_dict(obj.get("botProfiles")) if obj.get(
                "botProfiles") is not None else None,
            reply_setting=GroupChatReplySetting.from_dict(obj.get("replySetting")) if obj.get(
                "replySetting") is not None else None,
            user_profile=UserProfile.from_dict(obj.get("userProfile")) if obj.get("userProfile") is not None else None,
            group_info=GroupChatRoomInfo.from_dict(obj.get("groupInfo")) if obj.get("groupInfo") is not None else None

        )



from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, conlist


class PollingImageDetailDTO(BaseModel):
    task_id: Optional[StrictStr] = Field(None, alias="taskId")
    status: Optional[StrictStr] = None
    error_message: Optional[StrictStr] = Field(None, alias="errorMessage")
    file_url: Optional[conlist(StrictStr)] = Field(None, alias="fileUrl")

    __properties = ["taskId", "status", "errorMessage", "fileUrl"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PollingImageDetailDTO:
        """Create an instance of PollingImageDetailDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PollingImageDetailDTO:
        """Create an instance of PollingImageDetailDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PollingImageDetailDTO.parse_obj(obj)

        _obj = PollingImageDetailDTO.parse_obj({
            "task_id": obj.get("taskId"),
            "status": obj.get("status"),
            "error_message": obj.get("errorMessage"),
            "file_url": obj.get("fileUrl")
        })
        return _obj



# coding: utf-8

# flake8: noqa

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.1.3"

# import apis into sdk package
from xingchen.api.character_api_sub import CharacterApiSub
from xingchen.api.chat_api_sub import ChatApiSub
from xingchen.api.chat_message_api_sub import ChatMessageApiSub
from xingchen.api.groupchat_api_sub import GroupChatApiSub
from xingchen.api.chat_extract_message_api_sub import ChatExtractMessageApiSub
from xingchen.api.common_api_sub import CommonApiSub

# import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.api_client import ApiClient
from xingchen.configuration import Configuration
from xingchen.exceptions import OpenApiException
from xingchen.exceptions import ApiTypeError
from xingchen.exceptions import ApiValueError
from xingchen.exceptions import ApiKeyError
from xingchen.exceptions import ApiAttributeError
from xingchen.exceptions import ApiException

# import models into sdk package
from xingchen.models.advanced_settings import AdvancedSettings
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.character_advanced_config import CharacterAdvancedConfig
from xingchen.models.character_create_dto import CharacterCreateDTO
from xingchen.models.character_dto import CharacterDTO
from xingchen.models.character_key import CharacterKey
from xingchen.models.character_permission_config import CharacterPermissionConfig
from xingchen.models.character_query_dto import CharacterQueryDTO
from xingchen.models.character_query_where import CharacterQueryWhere
from xingchen.models.character_update_dto import CharacterUpdateDTO
from xingchen.models.character_version_create_or_update_dto import CharacterVersionCreateOrUpdateDTO
from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO
from xingchen.models.chat_history_query_where import ChatHistoryQueryWhere
from xingchen.models.chat_message_dto import ChatMessageDTO
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.chat_room_user_dto import ChatRoomUserDTO
from xingchen.models.context import Context
from xingchen.models.file_info_vo import FileInfoVO
from xingchen.models.gateway_context import GatewayContext
from xingchen.models.gateway_issued_params import GatewayIssuedParams
from xingchen.models.input import Input
from xingchen.models.message import Message
from xingchen.models.message_rating_request import MessageRatingRequest
from xingchen.models.meta import Meta
from xingchen.models.model_parameters import ModelParameters
from xingchen.models.page_result_character_dto import PageResultCharacterDTO
from xingchen.models.page_result_chat_message_dto import PageResultChatMessageDTO
from xingchen.models.repository import Repository
from xingchen.models.repository_info import RepositoryInfo
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO
from xingchen.models.result_dto_character_key import ResultDTOCharacterKey
from xingchen.models.result_dto_list_character_dto import ResultDTOListCharacterDTO
from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO
from xingchen.models.result_dto_page_result_chat_message_dto import ResultDTOPageResultChatMessageDTO
from xingchen.models.scenario import Scenario
from xingchen.models.sys_reminder_request import SysReminderRequest
from xingchen.models.user_profile import UserProfile
from xingchen.models.chat_context import ChatContext
from xingchen.models.function_call import Function, FunctionChoice, FunctionCall, FunctionChoiceType, Plugin, \
    PlanningApiInfo
from xingchen.models.custom.reset_history_request import ResetChatHistoryRequest
from xingchen.models.custom.character_model_parameters import CharacterModelParameters
from xingchen.models.custom.platform_publish_config import PlatformPublishConfig
from xingchen.models.custom.groupchat.group_chat_reply_setting import GroupChatReplySetting
from xingchen.models.custom.groupchat.group_chat_room_info import GroupChatRoomInfo
from xingchen.models.custom.groupchat.group_chat_ext_param import GroupChatExtParam
from xingchen.models.extract_data import ExtractData
from xingchen.models.stop_chat_request import StopChatRequest
from xingchen.models.character_desc_generated_request import CharacterDescGeneratedRequest
from xingchen.models.keyword import Keyword
from xingchen.models.memory import Memory
from xingchen.models.kv_memory_config import KVMemoryConfig
from xingchen.models.long_term_memory import LongTermMemory
from xingchen.models.reject_answer_plugin import RejectAnswerPlugin
from xingchen.models.reject_condition import RejectCondition
from xingchen.models.text_to_image_plugin import TextToImagePlugin
from xingchen.models.platform_plugin import PlatformPlugin
from xingchen.models.extract_memory_request import ExtractMemoryRequest
from xingchen.models.extract_data import ExtractData
from xingchen.models.extract_kv_dto import ExtractKVDTO
from xingchen.models.extract_summary_dto import ExtractSummaryDTO
from xingchen.models.file_conver_dto import FileConvertDTO
from xingchen.models.file_conver_request import FileConvertRequest
from xingchen.models.memory_summary import MemorySummary
from xingchen.models.polling_image_detail_dto import PollingImageDetailDTO
from xingchen.models.result_dto_character_desc_dto import ResultDTOCharacterDescDTO
from xingchen.models.result_dto_file_conver_dto import ResultDTOFileConvertDTO
from xingchen.models.result_dto_polling_image_detail_dto import ResultDTOPollingImageDetailDTO
from xingchen.models.result_dto_extract_kv_dto import ResultDTOExtractKVDTO
from xingchen.models.result_dto_extract_summary_dto import ResultDTOExtractSummaryDTO

from xingchen.models.custom.completion.completion_req_function import AcAReqFunction
from xingchen.models.custom.completion.completion_resp_function import AcARespFunction
from xingchen.models.custom.completion.completion_usage import AcAUsage
from xingchen.models.custom.completion.completion_req_message import AcAReqMessage
from xingchen.models.custom.completion.completion_resp_message import AcARespMessage
from xingchen.models.custom.completion.completion_req_tool import AcAReqTool
from xingchen.models.custom.completion.completion_resp_tool import AcARespTool
from xingchen.models.custom.completion.completion_req import AcACompletionReq
from xingchen.models.custom.completion.completion_resp import AcACompletionResp
from xingchen.api.completion_api_sub import AcACompletionApiSub



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""

import re  # noqa: F401
from typing import Union, Generator

import requests
from pydantic import Field
from pydantic import validate_arguments
from sseclient import SSEClient
from typing_extensions import Annotated
from xingchen.api_response import ApiResponse
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.aca_util import convert_chat_params, handle_sse_response
from xingchen.api_client import ApiClient
from xingchen.exceptions import (
    ApiTypeError
)
from xingchen.models.chat_req_params import ChatReqParams
from xingchen.models.custom import ChatResponse
from xingchen.models.stop_chat_request import StopChatRequest


class ChatApiSub:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def chat(self, chat_req_params: Annotated[ChatReqParams, Field(..., description="对话请求")],
             **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:
        """用户对话  # noqa: E501

         发起角色对话：   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat(chat_req_params, async_req=True)
        >>> result = thread.get()

        :param chat_req_params: 对话请求 (required)
        :type chat_req_params: ChatReqParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the chat_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.chat_with_http_info(chat_req_params, **kwargs)  # noqa: E501

    @validate_arguments
    def chat_with_http_info(self, chat_req_params: Annotated[ChatReqParams, Field(..., description="对话请求")],
                            **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:  # noqa: E501
        """用户对话  # noqa: E501

         发起角色对话：   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat_with_http_info(chat_req_params, async_req=True)
        >>> result = thread.get()

        :param chat_req_params: 对话请求 (required)
        :type chat_req_params: ChatReqParams
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'chat_req_params'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method chat" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['chat_req_params'] is not None:
            _body_params = _params['chat_req_params']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/event-stream'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "object",
        }

        # 参数转化
        version = self.version()
        if not version or 'v2'.__eq__(version):
            _body_params = convert_chat_params(chat_req_params)
            if chat_req_params.streaming:
                _header_params['X-DashScope-SSE'] = 'enable'
                _header_params['X-AcA-SSE'] = 'enable'

        is_stream = chat_req_params.streaming \
                    or 'enable' == _header_params.get('X-DashScope-SSE') \
                    or 'enable' == _header_params.get('X-AcA-SSE')
        path = '/{0}/api/chat/send'.format(version)
        host = self.api_client.configuration.host

        if is_stream:
            _header_params['x-fag-appcode'] = 'aca'
            _header_params['x-fag-servicename'] = 'aca-chat-send-sse'
            _header_params['Authorization'] = 'Bearer ' + self.api_client.configuration.access_token
            body_params = self.api_client.sanitize_for_serialization(_body_params)

            request = requests.post(
                host + path,
                headers=_header_params,
                json=body_params,
                stream=True
            )
            client = SSEClient(request)
            return (res for res in handle_sse_response(client))

        response = self.api_client.call_api(
            '/{0}/api/chat/send'.format(version), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

        return ChatResponse.from_dict(response)

    @validate_arguments
    def stop_chat(self, stop_chat_request: Annotated[StopChatRequest, Field(..., description="停止对话请求")],
                  **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the stop_chat_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.stop_chat_with_http_info(stop_chat_request, **kwargs)  # noqa: E501

    @validate_arguments
    def stop_chat_with_http_info(self, stop_chat_request: Annotated[
        StopChatRequest, Field(..., description="停止对话请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'extract_memory_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method  stop_chat" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['stop_chat_request'] is not None:
            _body_params = _params['stop_chat_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/chat/stop'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ChatRoomUserDTO(BaseModel):
    """
    聊天室用户  # noqa: E501
    """
    user_id: Optional[StrictStr] = Field(None, alias="userId", description="用户ID，若为普通用户，则为userId,;若为角色，则为characterId")
    biz_user_id: Optional[StrictStr] = Field(None, alias="bizUserId", description="若为ISV用户，则为ISV用户ID；若为角色，则为空")
    user_name: Optional[StrictStr] = Field(None, alias="userName", description="用户名称，若为普通用户，则为用户名称；若为角色，则为 characterName")
    user_type: Optional[StrictStr] = Field(None, alias="userType", description="用户类型，可以是 user（用户）或character（角色）")
    __properties = ["userId", "bizUserId", "userName", "userType"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatRoomUserDTO:
        """Create an instance of ChatRoomUserDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatRoomUserDTO:
        """Create an instance of ChatRoomUserDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatRoomUserDTO.parse_obj(obj)

        _obj = ChatRoomUserDTO.parse_obj({
            "user_id": obj.get("userId"),
            "biz_user_id": obj.get("bizUserId"),
            "user_name": obj.get("userName"),
            "user_type": obj.get("userType")
        })
        return _obj





import re  # noqa: F401

from pydantic import Field
from pydantic import validate_arguments
from typing_extensions import Annotated

from xingchen.api_client import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)
from xingchen.models.extract_memory_request import ExtractMemoryRequest
from xingchen.models.result_dto_extract_summary_dto import ResultDTOExtractSummaryDTO


class ChatExtractMessageApiSub:
    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def extract_memory_summary(self, extract_memory_request: Annotated[
        ExtractMemoryRequest, Field(..., description="抽取内容请求")],
                               **kwargs) -> ResultDTOExtractSummaryDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the extract_memory_summary_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.extract_memory_summary_with_http_info(extract_memory_request, **kwargs)  # noqa: E501

    @validate_arguments
    def extract_memory_summary_with_http_info(self, extract_memory_request: Annotated[
        ExtractMemoryRequest, Field(..., description="抽取内容请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'extract_memory_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method extract_memory_summary" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['extract_memory_request'] is not None:
            _body_params = _params['extract_memory_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOExtractSummaryDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/extract/summary'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def extract_memory_kv(self,
                          extract_memory_request: Annotated[ExtractMemoryRequest, Field(..., description="抽取内容请求")],
                          **kwargs) -> ResultDTOExtractSummaryDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the extract_memory_kv_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.extract_memory_kv_with_http_info(extract_memory_request, **kwargs)  # noqa: E501

    @validate_arguments
    def extract_memory_kv_with_http_info(self, extract_memory_request: Annotated[
        ExtractMemoryRequest, Field(..., description="抽取内容请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'extract_memory_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method extract_memory_kv" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['extract_memory_request'] is not None:
            _body_params = _params['extract_memory_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOExtractKVDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/extract/kv'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.character_dto import CharacterDTO  # noqa: E501

class TestCharacterDTO(unittest.TestCase):
    """CharacterDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CharacterDTO:
        """Test CharacterDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CharacterDTO`
        """
        model = CharacterDTO()  # noqa: E501
        if include_optional:
            return CharacterDTO(
                name = '0',
                avatar = xingchen.models.file_info_vo.FileInfoVO(
                    file_save_path = '', 
                    filename = '', 
                    file_url = '', ),
                introduction = '',
                basic_information = '',
                opening_line = '',
                traits = '',
                chat_example = '',
                type = '',
                chat_objective = '',
                advanced_config = xingchen.models.character_advanced_config.CharacterAdvancedConfig(
                    repository_info = xingchen.models.repository_info.RepositoryInfo(
                        repository_files = [
                            xingchen.models.repository.Repository(
                                file_save_path = '', 
                                filename = '', 
                                file_url = '', 
                                status = '', )
                            ], 
                        status = '', ), 
                    is_real_info = True, 
                    search_keyword = '', 
                    allow_send_image = True, 
                    image_style = '', 
                    allow_send_asr = True, 
                    asr_style = '', 
                    chat_description = '', ),
                character_id = '',
                version = 56,
                major_version = 56,
                gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                gmt_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user_id = '',
                modified_by = '',
                tags = [
                    ''
                    ],
                bubbles = [
                    ''
                    ],
                background_img_url = '',
                perm_config = xingchen.models.character_permission_config.CharacterPermissionConfig(
                    is_public = 56, 
                    allow_chat = 56, 
                    allow_api = 56, ),
                versions = [
                    56
                    ],
                manageable = True,
                creator = '',
                is_pre_configured = True
            )
        else:
            return CharacterDTO(
                name = '0',
                basic_information = '',
        )
        """

    def testCharacterDTO(self):
        """Test CharacterDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import json
import pprint
from typing import Dict

from pydantic import BaseModel, Field


class AcAReqFunction(BaseModel):
    """
    completions 接口请求参数
    """
    name: str = Field(..., title="function名", description="function名")
    description: str = Field(..., title="function描述", description="function描述")
    parameters: Dict = Field(..., title="function参数定义", description="function参数定义，json schema格式")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> 'AcAReqFunction':
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> 'AcAReqFunction':
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.parse_obj(obj)

        _obj = cls.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "parameters": obj.get("parameters")
        })
        return _obj


# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictInt, StrictStr

from typing import Optional

from xingchen.models import ResultDTOPollingImageDetailDTO
from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO
from xingchen.models.message_rating_request import MessageRatingRequest
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_page_result_chat_message_dto import ResultDTOPageResultChatMessageDTO
from xingchen.models.sys_reminder_request import SysReminderRequest
from xingchen.models.custom.reset_history_request import ResetChatHistoryRequest

from xingchen.api_client import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ChatMessageApiSub:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def chat_histories(self, chat_history_query_dto: Annotated[ChatHistoryQueryDTO, Field(..., description="对话请求")],
                       **kwargs) -> ResultDTOPageResultChatMessageDTO:  # noqa: E501
        """对话历史  # noqa: E501

         当前用户与角色的对话历史查询： - where: 查询条件：必传  - characterId: 必传  - startTime：开始时间戳，选传  - endTime: 结束时间戳，选传  - sessionId: 会话ID，宣传 - 排序：必传，默认根据创建时间倒排 - pageSize: 分页大小，选传，默认10 - pageNumber: 分页页码，宣传，默认1   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat_histories(chat_history_query_dto, async_req=True)
        >>> result = thread.get()

        :param chat_history_query_dto: 对话请求 (required)
        :type chat_history_query_dto: ChatHistoryQueryDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOPageResultChatMessageDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the chat_histories_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.chat_histories_with_http_info(chat_history_query_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def chat_histories_with_http_info(self, chat_history_query_dto: Annotated[
        ChatHistoryQueryDTO, Field(..., description="对话请求")], **kwargs) -> ApiResponse:  # noqa: E501
        """对话历史  # noqa: E501

         当前用户与角色的对话历史查询： - where: 查询条件：必传  - characterId: 必传  - startTime：开始时间戳，选传  - endTime: 结束时间戳，选传  - sessionId: 会话ID，宣传 - 排序：必传，默认根据创建时间倒排 - pageSize: 分页大小，选传，默认10 - pageNumber: 分页页码，宣传，默认1   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.chat_histories_with_http_info(chat_history_query_dto, async_req=True)
        >>> result = thread.get()

        :param chat_history_query_dto: 对话请求 (required)
        :type chat_history_query_dto: ChatHistoryQueryDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOPageResultChatMessageDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'chat_history_query_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method chat_histories" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['chat_history_query_dto'] is not None:
            _body_params = _params['chat_history_query_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOPageResultChatMessageDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/chat/message/histories'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def rate_message(self, message_rating_request: Annotated[MessageRatingRequest, Field(..., description="对话请求")],
                     **kwargs) -> ResultDTOBoolean:  # noqa: E501
        """消息评分  # noqa: E501

         评分请求参数： - 消息ID：必传 - 评分：必传，整型，[0-5]   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rate_message(message_rating_request, async_req=True)
        >>> result = thread.get()

        :param message_rating_request: 对话请求 (required)
        :type message_rating_request: MessageRatingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the rate_message_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.rate_message_with_http_info(message_rating_request, **kwargs)  # noqa: E501

    @validate_arguments
    def rate_message_with_http_info(self, message_rating_request: Annotated[
        MessageRatingRequest, Field(..., description="对话请求")], **kwargs) -> ApiResponse:  # noqa: E501
        """消息评分  # noqa: E501

         评分请求参数： - 消息ID：必传 - 评分：必传，整型，[0-5]   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.rate_message_with_http_info(message_rating_request, async_req=True)
        >>> result = thread.get()

        :param message_rating_request: 对话请求 (required)
        :type message_rating_request: MessageRatingRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'message_rating_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rate_message" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['message_rating_request'] is not None:
            _body_params = _params['message_rating_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/chat/rating'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def sys_reminder(self, sys_reminder_request: Annotated[SysReminderRequest, Field(..., description="对话请求")],
                     **kwargs) -> ResultDTOBoolean:  # noqa: E501
        """sys_reminder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.sys_reminder(sys_reminder_request, async_req=True)
        >>> result = thread.get()

        :param sys_reminder_request: 对话请求 (required)
        :type sys_reminder_request: SysReminderRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the sys_reminder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.sys_reminder_with_http_info(sys_reminder_request, **kwargs)  # noqa: E501

    @validate_arguments
    def sys_reminder_with_http_info(self, sys_reminder_request: Annotated[
        SysReminderRequest, Field(..., description="对话请求")], **kwargs) -> ApiResponse:  # noqa: E501
        """sys_reminder  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.sys_reminder_with_http_info(sys_reminder_request, async_req=True)
        >>> result = thread.get()

        :param sys_reminder_request: 对话请求 (required)
        :type sys_reminder_request: SysReminderRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'sys_reminder_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sys_reminder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['sys_reminder_request'] is not None:
            _body_params = _params['sys_reminder_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/chat/reminder'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def reset_chat_history(self, request: Annotated[
        ResetChatHistoryRequest, Field(..., description="重置对话")], **kwargs) -> ApiResponse:

        kwargs['_return_http_data_only'] = True

        if '_preload_content' in kwargs:
            message = "Error! Please call the sys_reminder_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)

        path = '/{0}/api/chat/reset'.format(self.version())
        request_body = request
        success_response_type = 'ResultDTOBoolean'

        return self.request_with_http_info(path, request_body, success_response_type, **kwargs)

    def request_with_http_info(self, path: str, request_body: any, success_response_type: str, **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'request_body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sys_reminder" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['request_body'] is not None:
            _body_params = _params['request_body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': success_response_type,
        }

        return self.api_client.call_api(
            path,
            'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def polling_image_detail(self, message_id: Annotated[StrictStr, Field(..., description="消息ID")],
                          user_id: Annotated[StrictInt, Field(..., description="用户ID")],
                          **kwargs) -> ResultDTOPollingImageDetailDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the character_details_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.polling_image_detail_with_http_info(message_id, user_id, **kwargs)  # noqa: E501

    @validate_arguments
    def polling_image_detail_with_http_info(self, message_id: Annotated[StrictStr, Field(..., description="角色ID")],
                                         user_id: Annotated[StrictInt, Field(..., description="用户ID")],
                                         **kwargs) -> ApiResponse:  # noqa: E501
        _params = locals()

        _all_params = [
            'message_id',
            'user_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method polling_image_detail" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('message_id') is not None:  # noqa: E501
            _query_params.append(('messageId', _params['message_id']))

        if _params.get('user_id') is not None:  # noqa: E501
            _query_params.append(('userId', _params['user_id']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOPollingImageDetailDTO",
        }

        return self.api_client.call_api(
            '/{api_version}/api/chat/polling/image'.format(api_version=self.api_client.configuration.api_version), 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



import json
import pprint
from typing import Optional

from pydantic import BaseModel, Field, StrictInt


class AcAUsage(BaseModel):
    """
    用量统计
    """
    prompt_tokens: Optional[StrictInt] = Field(None, description="Prompt token 数")
    completion_tokens: Optional[StrictInt] = Field(None, description="模型生成 token 数")
    total_tokens: Optional[StrictInt] = Field(None, description="token总数")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.dict(by_alias=True))

    def to_dict(self) -> dict:
        """Returns the dictionary representation of the model using alias"""
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> 'AcAUsage':
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> 'AcAUsage':
        if obj is None:
            return None
        if not isinstance(obj, dict):
            return AcAUsage.parse_obj(obj)
        return AcAUsage.parse_obj({
            'prompt_tokens': obj.get('prompt_tokens'),
            'completion_tokens': obj.get('completion_tokens'),
            'total_tokens': obj.get('total_tokens')
        })
